@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002-2012 BalaBit IT Ltd, Budapest, Hungary
+ * Copyright (c) 2002-2013 BalaBit IT Ltd, Budapest, Hungary
  * Copyright (c) 1998-2012 Balázs Scheidler
  *
  * This library is free software; you can redistribute it and/or
@@ -30,7 +30,10 @@
 #include "cfg-lexer.h"
 #include "cfg-parser.h"
 #include "persist-state.h"
-#include "templates.h"
+#include "template/templates.h"
+#include "host-resolve.h"
+#include "type-hinting.h"
+#include "stats/stats.h"
 
 #include <sys/types.h>
 #include <regex.h>
@@ -52,43 +55,43 @@ typedef struct _PersistConfig PersistConfig;
 /* configuration data as loaded from the config file */
 struct _GlobalConfig
 {
-  /* version number of the configuration file, hex-encoded syslog-ng major/minor, e.g. 0x0201 is syslog-ng 2.1 format */
+  /* version number specified by the user, set _after_ parsing is complete */
+  /* hex-encoded syslog-ng major/minor, e.g. 0x0201 is syslog-ng 2.1 format */
   gint user_version;
-  /* version parsed from the config file, to be applied in _version */
+  
+  /* version number as parsed from the configuration file, it can be set
+   * multiple times if the user uses @version multiple times */
   gint parsed_version;
-  gchar *filename;
+  const gchar *filename;
   GList *plugins;
   GList *candidate_plugins;
   gboolean autoload_compiled_modules;
   CfgLexer *lexer;
 
-  gint stats_freq;
-  gint stats_level;
+  StatsOptions stats_options;
   gint mark_freq;
   gint flush_lines;
   gint mark_mode;
   gint flush_timeout;
   gboolean threaded;
+  gboolean pass_unix_credentials;
   gboolean chain_hostnames;
-  gboolean normalize_hostnames;
   gboolean keep_hostname;
   gboolean check_hostname;
   gboolean bad_hostname_compiled;
   regex_t bad_hostname;
   gchar *bad_hostname_re;
-  gboolean use_fqdn;
-  gboolean use_dns;
-  gboolean use_dns_cache;
   gint dns_cache_size, dns_cache_expire, dns_cache_expire_failed;
   gchar *dns_cache_hosts;
+  gchar *custom_domain;
   gint time_reopen;
   gint time_reap;
   gint suppress;
+  gint type_cast_strictness;
 
   gint log_fifo_size;
   gint log_msg_size;
 
-  gint follow_freq;
   gboolean create_dirs;
   gint file_uid;
   gint file_gid;
@@ -98,10 +101,13 @@ struct _GlobalConfig
   gint dir_gid;
   gint dir_perm;
 
+  gboolean use_uniqid;
+
   gboolean keep_timestamp;  
 
   gchar *recv_time_zone;
   LogTemplateOptions template_options;
+  HostResolveOptions host_resolve_options;
   
   gchar *file_template_name;
   gchar *proto_template_name;
@@ -111,6 +117,7 @@ struct _GlobalConfig
   
   PersistConfig *persist;
   PersistState *state;
+  GHashTable *module_config;
   
   CfgTree tree;
 
@@ -134,9 +141,12 @@ gint cfg_ts_format_value(gchar *format);
 void cfg_set_version(GlobalConfig *self, gint version);
 void cfg_load_candidate_modules(GlobalConfig *self);
 
+void cfg_set_global_paths(GlobalConfig *self);
+
 GlobalConfig *cfg_new(gint version);
 gboolean cfg_run_parser(GlobalConfig *self, CfgLexer *lexer, CfgParser *parser, gpointer *result, gpointer arg);
-gboolean cfg_read_config(GlobalConfig *cfg, gchar *fname, gboolean syntax_only, gchar *preprocess_into);
+gboolean cfg_read_config(GlobalConfig *cfg, const gchar *fname, gboolean syntax_only, gchar *preprocess_into);
+gboolean cfg_load_config(GlobalConfig *self, gchar *config_string, gboolean syntax_only, gchar *preprocess_into);
 void cfg_free(GlobalConfig *self);
 gboolean cfg_init(GlobalConfig *cfg);
 gboolean cfg_deinit(GlobalConfig *cfg);
@@ -158,4 +168,14 @@ cfg_is_config_version_older(GlobalConfig *cfg, gint req)
   return TRUE;
 }
 
+static inline void
+cfg_set_use_uniqid(gboolean flag)
+{
+  configuration->use_uniqid = !!flag;
+}
+
+gint cfg_get_user_version(const GlobalConfig *cfg);
+gint cfg_get_parsed_version(const GlobalConfig *cfg);
+const gchar* cfg_get_filename(const GlobalConfig *cfg);
+
 #endif
